package com.waimai.web.admin.service;

import java.util.List;
import com.waimai.web.admin.domain.Food;

/**
 * 食品Service接口
 * 
 * @author callmeyan
 * @date 2023-03-24
 */
public interface IFoodService 
{
    /**
     * 查询食品
     * 
     * @param id 食品主键
     * @return 食品
     */
    public Food selectFoodById(Long id);

    /**
     * 查询食品列表
     * 
     * @param food 食品
     * @return 食品集合
     */
    public List<Food> selectFoodList(Food food);

    /**
     * 新增食品
     * 
     * @param food 食品
     * @return 结果
     */
    public int insertFood(Food food);

    /**
     * 修改食品
     * 
     * @param food 食品
     * @return 结果
     */
    public int updateFood(Food food);

    /**
     * 批量删除食品
     * 
     * @param ids 需要删除的食品主键集合
     * @return 结果
     */
    public int deleteFoodByIds(Long[] ids);

    /**
     * 删除食品信息
     * 
     * @param id 食品主键
     * @return 结果
     */
    public int deleteFoodById(Long id);
}
